@@ -360,7 +360,7 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
     #start iterations
     iteration <- 1
     nllk <- 0
-    primal_change <- NULL
+    resid_change <- NULL
     dual_change <- NULL
     nllk_change <- NULL
     z_change <- NULL
@@ -458,7 +458,8 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
       newdiff <- sum((tempcommon-z[commonindex])^2)
       newnorm <- sum(z^2)
       relchange <- newdiff / (1+olddiff)
-      primal_change <- c(primal_change,relchange)
+      resid <- abs(newdiff-olddiff) / (1+olddiff)  
+      resid_change <- c(resid_change, resid)
       
       #update l
       for(i in 1:nsubj){
@@ -481,7 +482,7 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
       new_nllk_change <- abs(nllk-oldlik)/(1+oldlik)
       nllk_change <- c(nllk_change,new_nllk_change)
       
-      kkt_cur <- max(newzdiff, reldualchange, new_nllk_change)
+      kkt_cur <- max(resid, reldualchange, new_nllk_change)#newzdiff
       if(iteration > maxit | 
          (iteration>2 & kkt_cur < tol )) {
         nllk <- oldlik; break}
@@ -504,7 +505,7 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
     workingparm <- t(sapply(1:nrow(parm),function(kkk) invmapf(parm[kkk,],M,ncolx)))
     return(list(working_parm=workingparm,
                 common_parm=z,
-                kkt=pmax(z_change[-1],dual_change[-1],nllk_change[-1]),
+                kkt=pmax(resid_change[-1],dual_change[-1],nllk_change[-1]),
                 nllk=nllk))
     #################
     
@@ -559,7 +560,7 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
     #start iterations
     iteration <- 1
     nllk <- 0
-    primal_change <- NULL
+    resid_change <- NULL
     dual_change <- NULL
     nllk_change <- NULL
     z_change <- NULL
@@ -672,7 +673,8 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
       newzdiff <- abs(newznorm - oldznorm) / (1+oldznorm)
       z_change <- c(z_change, newzdiff)
       relchange <- newdiff / (1+olddiff)
-      primal_change <- c(primal_change,relchange)
+      resid <- abs(newdiff-olddiff) / (1+olddiff)  
+      resid_change <- c(resid_change, resid)
       
       #update l
       for(i in 1:nsubj){
@@ -693,7 +695,7 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
       new_nllk_change <- abs(nllk-oldlik)/(1+oldlik)
       nllk_change <- c(nllk_change,new_nllk_change)
       
-      kkt_cur <- max(newzdiff, reldualchange, new_nllk_change)
+      kkt_cur <- max(resid, reldualchange, new_nllk_change)#newzdiff
       if(iteration > maxit | 
          (iteration>2 & kkt_cur < tol )) {
         nllk <- oldlik; break}
@@ -715,7 +717,7 @@ dist_learn2 <- function(ylist, xlist, timelist, prior_init, tpm_init,
     workingparm <- t(sapply(1:nrow(parm),function(kkk) invmapf(parm[kkk,],M,ncolx)))
     return(list(working_parm=workingparm,
                 common_parm=z,
-                kkt=pmax(z_change[-1],dual_change[-1],nllk_change[-1]),
+                kkt=pmax(resid_change[-1],dual_change[-1],nllk_change[-1]),
                 nllk=nllk))
   }
   
